'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _isArray = require('lodash/isArray');

var _isArray2 = _interopRequireDefault(_isArray);

var _isPlainObject = require('lodash/isPlainObject');

var _isPlainObject2 = _interopRequireDefault(_isPlainObject);

var _Crio = require('./Crio');

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @module crio
 */

/**
 * @function crio
 *
 * @description
 * build a new crio object based on the object passed
 *
 * @param {*} [object={}] object to convert to crio
 *
 * @returns {CrioArray|CrioObject} object that has been crioed
 */


// Crio
// external dependencies
var crio = function crio() {
  var object = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  if ((0, _isArray2.default)(object)) {
    return new _Crio.CrioArray(object);
  }

  if ((0, _isPlainObject2.default)(object)) {
    return new _Crio.CrioObject(object);
  }

  if ((0, _utils.isCrio)(object)) {
    return object;
  }

  throw new TypeError('Object passed must be either an array or a plain object.');
};

/**
 * @function crio.array
 *
 * @description
 * convenience method for making crio arrays
 *
 * @param {Array<*>} array array to crio
 * @returns {CrioArray} crio array
 */


// utils
crio.array = function () {
  var array = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

  if (!(0, _isArray2.default)(array)) {
    throw new TypeError('Object passed must be an array.');
  }

  return crio(array);
};

/**
 * @function crio.isArray
 *
 * @description
 * check if object is a crio array
 *
 * @param {*} object object to test
 * @returns {boolean} is the object a crio array
 */
crio.isArray = function (object) {
  return (0, _utils.isCrio)(object) && object.isArray();
};

crio.isCrio = _utils.isCrio;

/**
 * @function crio.isObject
 *
 * @description
 * check if object is a crio object
 *
 * @param {*} object object to test
 * @returns {boolean} is the object a crio object
 */
crio.isObject = function (object) {
  return (0, _utils.isCrio)(object) && object.isObject();
};

/**
 * @function crio.object
 *
 * @description
 * convenience method for making crio objects
 *
 * @param {Object} object object to crio
 * @returns {CrioObject} crio object
 */
crio.object = function () {
  var object = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  if (!(0, _isPlainObject2.default)(object)) {
    throw new TypeError('Object passed must be a plain object.');
  }

  return crio(object);
};

exports.default = crio;
module.exports = exports['default'];